@@ -104,7 +104,7 @@ class Gui:
     def get_entries_as_args(self) -> list:
         return [self.inputs_dict[input_name].get() for input_name in self.inputs]
 
-    def get(self, entry):
-        return self.inputs_dict[entry].get()
+    def get(self, entry_name):
+        return self.inputs_dict[entry_name].get()
 
 
